@@ -92,18 +92,21 @@ def _get_locations(pkgs, package_dir):
     return locations
 
 
-def generate_cmake_file(package_name, version, scripts, package_dir, pkgs, modules):
+def generate_cmake_file(package_name, version, scripts, package_dir, pkgs, modules, setup_module=None):
     """
     Generate lines to add to a cmake file which will set variables.
 
     :param version: str, format 'int.int.int'
     :param scripts: [list of str]: relative paths to scripts
     :param package_dir: {modulename: path}
-    :pkgs: [list of str] python_packages declared in catkin package
-    :modules: [list of str] python modules
+    :param pkgs: [list of str] python_packages declared in catkin package
+    :param modules: [list of str] python modules
+    :param setup_module: str, setuptools or distutils
     """
     prefix = '%s_SETUP_PY' % package_name
     result = []
+    if setup_module:
+        result.append(r'set(%s_SETUP_MODULE "%s")' % (prefix, setup_module))
     result.append(r'set(%s_VERSION "%s")' % (prefix, version))
     result.append(r'set(%s_SCRIPTS "%s")' % (prefix, ';'.join(scripts)))
 
@@ -160,7 +163,7 @@ def generate_cmake_file(package_name, version, scripts, package_dir, pkgs, modul
     return result
 
 
-def _create_mock_setup_function(package_name, outfile):
+def _create_mock_setup_function(setup_module, package_name, outfile):
     """
     Create a function to call instead of distutils.core.setup or setuptools.setup.
 
@@ -202,7 +205,8 @@ def _create_mock_setup_function(package_name, outfile):
                                      scripts=scripts,
                                      package_dir=package_dir,
                                      pkgs=pkgs,
-                                     modules=modules)
+                                     modules=modules,
+                                     setup_module=setup_module)
         with open(outfile, 'w') as out:
             out.write('\n'.join(result))
 
@@ -235,12 +239,11 @@ def main():
     # context of evaluating setup.py
     backup_modules = {}
     try:
-        fake_setup = _create_mock_setup_function(
-            package_name=args.package_name, outfile=args.outfile)
 
         for module in setup_modules:
             backup_modules[id(module)] = module.setup
-            module.setup = fake_setup
+            module.setup = _create_mock_setup_function(
+                setup_module=module.__name__, package_name=args.package_name, outfile=args.outfile)
 
         runpy.run_path(args.setupfile_path)
     finally:
