@@ -55,6 +55,21 @@ class InterrogateSetupTest(unittest.TestCase):
                           'set(pack1_SETUP_PY_MODULES "")',
                           'set(pack1_SETUP_PY_MODULE_DIRS "")'],
                          cmake_lines)
+        cmake_lines = (generate_cmake_file(package_name='pack1',
+                                           version='0.0.1',
+                                           scripts=[],
+                                           package_dir={},
+                                           pkgs=['foo', 'bar', 'bar.sub'],
+                                           modules=[],
+                                           setup_module='setuptools'))
+        self.assertEqual(['set(pack1_SETUP_PY_SETUP_MODULE "setuptools")',
+                          'set(pack1_SETUP_PY_VERSION "0.0.1")',
+                          'set(pack1_SETUP_PY_SCRIPTS "")',
+                          'set(pack1_SETUP_PY_PACKAGES "foo;bar")',
+                          'set(pack1_SETUP_PY_PACKAGE_DIRS "foo;bar")',
+                          'set(pack1_SETUP_PY_MODULES "")',
+                          'set(pack1_SETUP_PY_MODULE_DIRS "")'],
+                         cmake_lines)
 
     def test_get_locations(self):
         self.assertEqual({'foo': 'foo'}, _get_locations(['foo'], {}))
@@ -116,14 +131,15 @@ class InterrogateSetupTest(unittest.TestCase):
         try:
             rootdir = tempfile.mkdtemp()
             outfile = os.path.join(rootdir, 'out.cmake')
-            fake_setup = _create_mock_setup_function('foo', outfile)
+            fake_setup = _create_mock_setup_function('setuptools', 'foo', outfile)
             self.assertRaises(RuntimeError, fake_setup, package_dir={'': 'src'})
             # simple setup
             fake_setup(version='0.1.1', package_dir={'': 'src'})
             self.assertTrue(os.path.isfile(outfile))
             with open(outfile, 'r') as fhand:
                 contents = fhand.read()
-            self.assertEqual("""set(foo_SETUP_PY_VERSION "0.1.1")
+            self.assertEqual("""set(foo_SETUP_PY_SETUP_MODULE "setuptools")
+set(foo_SETUP_PY_VERSION "0.1.1")
 set(foo_SETUP_PY_SCRIPTS "")
 set(foo_SETUP_PY_PACKAGES "")
 set(foo_SETUP_PY_PACKAGE_DIRS "")
@@ -135,7 +151,8 @@ set(foo_SETUP_PY_MODULE_DIRS "")""", contents)
             self.assertTrue(os.path.isfile(outfile))
             with open(outfile, 'r') as fhand:
                 contents = fhand.read()
-            self.assertEqual("""set(foo_SETUP_PY_VERSION "0.1.1")
+            self.assertEqual("""set(foo_SETUP_PY_SETUP_MODULE "setuptools")
+set(foo_SETUP_PY_VERSION "0.1.1")
 set(foo_SETUP_PY_SCRIPTS "bin/foo;nodes/bar")
 set(foo_SETUP_PY_PACKAGES "foo;bar")
 set(foo_SETUP_PY_PACKAGE_DIRS "foo;bar")
@@ -147,7 +164,8 @@ set(foo_SETUP_PY_MODULE_DIRS "")""", contents)
             self.assertTrue(os.path.isfile(outfile))
             with open(outfile, 'r') as fhand:
                 contents = fhand.read()
-            self.assertEqual("""set(foo_SETUP_PY_VERSION "0.1.1")
+            self.assertEqual("""set(foo_SETUP_PY_SETUP_MODULE "setuptools")
+set(foo_SETUP_PY_VERSION "0.1.1")
 set(foo_SETUP_PY_SCRIPTS "")
 set(foo_SETUP_PY_PACKAGES "foo;bar")
 set(foo_SETUP_PY_PACKAGE_DIRS "src;lib")
